@@ -1,4 +1,6 @@
 from datetime import date
+from functools import partial
+from re import Match
 from typing import Any
 
 from jinja2 import BaseLoader, Environment, Template
@@ -20,11 +22,16 @@ def update(
         assert file.jinja_rel_path, "No valid jinja template found."
         replacement_str = file.jinja_rel_path.read_text()
 
-    variables = _get_variables(file, update)
-    pattern = render_jinja(file.pattern, variables)
-    replacement = render_jinja(replacement_str, variables)
+    var_getter = partial(_get_variables, file, update)
+    pattern = render_jinja(file.pattern, var_getter())
 
-    return cached_compile(pattern).sub(replacement, content)
+    # re.sub can take a callable as the replacement argument rather than a
+    # string. This callable accepts a match and returns a string. For each
+    # match which is found, re.sub will call repl with the match, and
+    # replace the found pattern with the output string of the user supplied
+    # repl function.
+    repl = lambda m: render_jinja(replacement_str, var_getter(m))
+    return cached_compile(pattern).sub(repl, content)
 
 
 def render_pattern(
@@ -47,6 +54,7 @@ def _tmpl(jinja: str) -> Template:
 def _get_variables(
     versioned_file: VersionedFile,
     update: ChangelogUpdate,
+    match: Match | None = None,
 ) -> dict[str, Any]:
     return dict(
         new_version=update.new_version,
@@ -54,4 +62,5 @@ def _get_variables(
         today=date.today(),
         sections=update.release_notes.dict(),
         context=versioned_file.context,
+        match=match,
     )
